==> natsort-3.5.0.zip: natsort-3.5.0/setup.py <==
#! /usr/bin/env python

# Std. lib imports
import re
import sys
from os.path import join

# Non-std lib imports
from setuptools import setup
from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    """Custom command to run pytest on all code."""

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        err1 = pytest.main(['--cov', 'natsort', '--flakes', '--pep8'])
        err2 = pytest.main(['--doctest-modules', 'natsort'])
        err3 = pytest.main(['README.rst',
                            'docs/source/intro.rst',
                            'docs/source/examples.rst'])
        return err1 | err2 | err3


# Read the natsort.py file for the module version number
VERSIONFILE = join('natsort', '_version.py')
versionsearch = re.compile(r"^__version__ = ['\"]([^'\"]*)['\"]")
with open(VERSIONFILE, "rt") as fl:
    for line in fl:
        m = versionsearch.search(line)
        if m:
            VERSION = m.group(1)
            break
    else:
        s = "Unable to locate version string in {0}"
        raise RuntimeError(s.format(VERSIONFILE))


# Read in the documentation for the long_description
DESCRIPTION = 'Sort lists naturally'
try:
    with open('README.rst') as fl:
        LONG_DESCRIPTION = fl.read()
except IOError:
    LONG_DESCRIPTION = DESCRIPTION


# The argparse module was introduced in python 2.7 or python 3.2
REQUIRES = 'argparse' if sys.version[:3] in ('2.6', '3.0', '3.1') else ''


# The setup parameters
setup(
    name='natsort',
    version=VERSION,
    author='Seth M. Morton',
    author_email='drtuba78@gmail.com',
    url='https://github.com/SethMMorton/natsort',
    license='MIT',
    install_requires=REQUIRES,
    packages=['natsort'],
    entry_points={'console_scripts': ['natsort = natsort.__main__:main']},
    tests_require=['pytest', 'pytest-pep8',
                   'pytest-flakes', 'pytest-cov'],
    cmdclass={'test': PyTest},
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Utilities',
    )
)

==> natsort-3.5.2.zip: natsort-3.5.2/setup.py <==
#! /usr/bin/env python

# Std. lib imports
import re
import sys
from os.path import join

# Non-std lib imports
from setuptools import setup
from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    """Custom command to run pytest on all code."""

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        err1 = pytest.main(['--cov', 'natsort',
                            '--cov-report', 'term-missing',
                            '--flakes', '--pep8'])
        err2 = pytest.main(['--doctest-modules', 'natsort'])
        err3 = pytest.main(['README.rst',
                            'docs/source/intro.rst',
                            'docs/source/examples.rst'])
        return err1 | err2 | err3


# Read the natsort.py file for the module version number
VERSIONFILE = join('natsort', '_version.py')
versionsearch = re.compile(r"^__version__ = ['\"]([^'\"]*)['\"]")
with open(VERSIONFILE, "rt") as fl:
    for line in fl:
        m = versionsearch.search(line)
        if m:
            VERSION = m.group(1)
            break
    else:
        s = "Unable to locate version string in {0}"
        raise RuntimeError(s.format(VERSIONFILE))


# Read in the documentation for the long_description
DESCRIPTION = 'Sort lists naturally'
try:
    with open('README.rst') as fl:
        LONG_DESCRIPTION = fl.read()
except IOError:
    LONG_DESCRIPTION = DESCRIPTION


# The argparse module was introduced in python 2.7 or python 3.2
REQUIRES = 'argparse' if sys.version[:3] in ('2.6', '3.0', '3.1') else ''


# The setup parameters
setup(
    name='natsort',
    version=VERSION,
    author='Seth M. Morton',
    author_email='drtuba78@gmail.com',
    url='https://github.com/SethMMorton/natsort',
    license='MIT',
    install_requires=REQUIRES,
    packages=['natsort'],
    entry_points={'console_scripts': ['natsort = natsort.__main__:main']},
    tests_require=['pytest', 'pytest-pep8',
                   'pytest-flakes', 'pytest-cov'],
    cmdclass={'test': PyTest},
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Utilities',
    )
)
